# Python implementation of Hack assembler

![Linter](https://github.com/ITD27M01/hack-assembler/workflows/Linter/badge.svg)

[nand2tetris project6](https://www.nand2tetris.org/project06)

    assembler Prog.asm